pub enum PhaseTickResult {
Ran {
phase: String,
items_processed: i32,
items_failed: i32,
error: Option<String>,
},
PhaseNotImplemented {
phase: String,
},
UnknownPhase {
phase: Option<String>,
known_phases: Vec<String>,
},
}Expand description
The outcome of dispatching one phase.
Variants
Ran
Fields
PhaseNotImplemented
No implementation is registered for this phase in run_phase_once yet.
UnknownPhase
The ?phase= value is not one of the twelve canonical names.
Implementations
Sourceimpl PhaseTickResult
impl PhaseTickResult
fn of(phase: CreditRegistrationPhase, tick: PhaseTick) -> Self