register_new_completions_via_suotar

Function register_new_completions_via_suotar 

async fn register_new_completions_via_suotar(
    app_conf: Data<ApplicationConfiguration>,
    pool: Data<PgPool>,
    payload: Json<RegisterNewCompletionsViaSuotarPayload>,
) -> ControllerResult<HttpResponse>
Opts a module’s new completions of linked students into Suotar, which only support can do by hand: a spec that creates its own course needs its completions on the pipeline.