run_tick

Function run_tick 

async fn run_tick(
    app_conf: Data<ApplicationConfiguration>,
    pool: Data<PgPool>,
    query: Query<RunTickQuery>,
) -> ControllerResult<HttpResponse>
POST /api/v0/mock-suotar/control/run-tick?phase={phase}

Runs one iteration of one pipeline phase. 200 when the phase ran, 501 phaseNotImplemented when no implementation is registered for it, 400 unknownPhase for a name that is not a phase.